import { BrowserPlugin } from '@snowplow/browser-tracker-core';
interface GACookiesPluginOptions {
    ua?: boolean;
    ga4?: boolean;
    ga4MeasurementId?: string | string[];
    cookiePrefix?: string | string[];
}
/**
 * Captures the GA cookies on a page and sends as context on each event
 * @param pluginOptions.ua - Send Universal Analytics specific cookie values.
 * @param pluginOptions.ga4 - Send Google Analytics 4 specific cookie values.
 * @param pluginOptions.ga4MeasurementId - Measurement id/ids to search the Google Analytics 4 session cookie. Can be a single measurement id as a string or an array of measurement id strings. The cookie has the form of _ga_<container-id> where <container-id> is the data stream container id.
 * @param pluginOptions.cookiePrefix - Cookie prefix set on the Google Analytics 4 cookies using the cookie_prefix option of the gtag.js tracker.
 */
declare function GaCookiesPlugin(pluginOptions?: GACookiesPluginOptions): BrowserPlugin;
export { GaCookiesPlugin };
