/*!
 * Attaches GA cookie data to Snowplow events v4.5.0 (http://bit.ly/sp-js)
 * Copyright 2022 Snowplow Analytics Ltd, 2010 Anthon Pang
 * Licensed under BSD-3-Clause
 */

(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
  typeof define === 'function' && define.amd ? define(['exports'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.snowplowGaCookies = {}));
})(this, (function (exports) { 'use strict';

  /******************************************************************************
  Copyright (c) Microsoft Corporation.

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
  REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
  INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
  LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
  OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  PERFORMANCE OF THIS SOFTWARE.
  ***************************************************************************** */

  var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
  };

  function __spreadArray(to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
  }

  typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
    var e = new Error(message);
    return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
  };

  /*!
   * Core functionality for Snowplow Browser trackers v4.5.0 (http://bit.ly/sp-js)
   * Copyright 2022 Snowplow Analytics Ltd, 2010 Anthon Pang
   * Licensed under BSD-3-Clause
   */
  /**
   * Get and set the cookies associated with the current document in browser
   * This implementation always returns a string, returns the cookie value if only name is specified
   *
   * @param name - The cookie name (required)
   * @param value - The cookie value
   * @param ttl - The cookie Time To Live (seconds)
   * @param path - The cookies path
   * @param domain - The cookies domain
   * @param samesite - The cookies samesite attribute
   * @param secure - Boolean to specify if cookie should be secure
   * @returns string The cookies value
   */
  function cookie(name, value, ttl, path, domain, samesite, secure) {
      if (arguments.length > 1) {
          return (document.cookie =
              name +
                  '=' +
                  encodeURIComponent(value !== null && value !== void 0 ? value : '') +
                  (ttl ? '; Expires=' + new Date(+new Date() + ttl * 1000).toUTCString() : '') +
                  (path ? '; Path=' + path : '') +
                  (domain ? '; Domain=' + domain : '') +
                  (samesite ? '; SameSite=' + samesite : '') +
                  (secure ? '; Secure' : ''));
      }
      return decodeURIComponent((('; ' + document.cookie).split('; ' + name + '=')[1] || '').split(';')[0]);
  }

  var UNIVERSAL_ANALYTICS_COOKIES_SCHEMA = 'iglu:com.google.analytics/cookies/jsonschema/1-0-0';
  var GOOGLE_ANALYTICS_4_COOKIES_SCHEMA = 'iglu:com.google.ga4/cookies/jsonschema/1-0-0';

  var defaultPluginOptions = {
      ua: false,
      ga4: true,
      ga4MeasurementId: '',
      cookiePrefix: [],
  };
  /**
   * Captures the GA cookies on a page and sends as context on each event
   * @param pluginOptions.ua - Send Universal Analytics specific cookie values.
   * @param pluginOptions.ga4 - Send Google Analytics 4 specific cookie values.
   * @param pluginOptions.ga4MeasurementId - Measurement id/ids to search the Google Analytics 4 session cookie. Can be a single measurement id as a string or an array of measurement id strings. The cookie has the form of _ga_<container-id> where <container-id> is the data stream container id.
   * @param pluginOptions.cookiePrefix - Cookie prefix set on the Google Analytics 4 cookies using the cookie_prefix option of the gtag.js tracker.
   */
  function GaCookiesPlugin(pluginOptions) {
      if (pluginOptions === void 0) { pluginOptions = defaultPluginOptions; }
      return {
          contexts: function () {
              var contexts = [];
              var _a = __assign(__assign({}, defaultPluginOptions), pluginOptions), ga4 = _a.ga4, ga4MeasurementId = _a.ga4MeasurementId, ua = _a.ua, cookiePrefix = _a.cookiePrefix;
              var GA_USER_COOKIE = '_ga';
              var GA4_MEASUREMENT_ID_PREFIX = 'G-';
              var GA4_COOKIE_PREFIX = '_ga_';
              if (ua) {
                  var uaCookiesContext_1 = {
                      schema: UNIVERSAL_ANALYTICS_COOKIES_SCHEMA,
                      data: {},
                  };
                  ['__utma', '__utmb', '__utmc', '__utmv', '__utmz', GA_USER_COOKIE].forEach(function (cookieType) {
                      var value = cookie(cookieType);
                      if (value) {
                          uaCookiesContext_1.data[cookieType] = value;
                      }
                  });
                  contexts.push(uaCookiesContext_1);
              }
              if (ga4) {
                  var cookiePrefixes = Array.isArray(cookiePrefix) ? __spreadArray([], cookiePrefix, true) : [cookiePrefix];
                  /* We also will search for the default (no prefix) in every case. */
                  cookiePrefixes.unshift('');
                  cookiePrefixes.forEach(function (prefix) {
                      var userCookie = cookie(prefix + GA_USER_COOKIE);
                      var sessionCookies = [];
                      if (ga4MeasurementId) {
                          var measurementIdentifiers = Array.isArray(ga4MeasurementId) ? __spreadArray([], ga4MeasurementId, true) : [ga4MeasurementId];
                          measurementIdentifiers.forEach(function (cookieIdentifier) {
                              var sessionCookieValue = cookie(prefix + cookieIdentifier.replace(GA4_MEASUREMENT_ID_PREFIX, GA4_COOKIE_PREFIX));
                              if (sessionCookieValue) {
                                  sessionCookies.push({
                                      measurement_id: cookieIdentifier,
                                      session_cookie: sessionCookieValue,
                                  });
                              }
                          });
                      }
                      if (!userCookie && !sessionCookies.length) {
                          return;
                      }
                      var ga4CookiesContext = {
                          schema: GOOGLE_ANALYTICS_4_COOKIES_SCHEMA,
                          data: {
                              _ga: userCookie,
                              session_cookies: sessionCookies.length ? sessionCookies : undefined,
                              cookie_prefix: prefix || undefined,
                          },
                      };
                      contexts.push(ga4CookiesContext);
                  });
              }
              return contexts;
          },
      };
  }

  exports.GaCookiesPlugin = GaCookiesPlugin;

  Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=index.umd.js.map
